@@ -3,10 +3,31 @@
 import string, textwrap
 import numpy as np
 from . import crm, infrared, molar, spectro, vindta
+from .vindta import (
+    Dbs,
+    read_dbs,
+    read_logfile,
+    get_logfile_index,
+    get_sample_blanks,
+    blank_progression,
+    centre_and_scale,
+    de_centre_and_scale,
+    get_session_blanks,
+    blank_correction,
+    get_blank_corrections,
+    get_density,
+    get_standard_calibrations,
+    get_session_calibrations,
+    calibrate_dic,
+    plot_session_blanks,
+    plot_blanks,
+    plot_k_dic,
+    plot_dic_offset,
+    concat,
+)
 
 __all__ = ["crm", "infrared", "molar", "spectro", "vindta"]
-
-__version__ = "0.0.4"
+__version__ = "0.0.8"
 
 
 lcletter = dict(zip(range(1, 27), string.ascii_lowercase))
